@@ -5,11 +5,10 @@ import jinja2
 import re
 import asyncio
 from pathlib import Path
-from .data_source import servers,set_shipparams,tiers,number_url_homes
+from .data_source import servers,set_shipparams,set_shipRecentparams,tiers,number_url_homes
 from .utils import match_keywords
 from nonebot_plugin_htmlrender import html_to_pic,text_to_pic
 from nonebot.adapters.onebot.v11 import MessageSegment,ActionFailed
-#from nonebot.adapters.onebot.v11.exception import ActionFailed
 from.publicAPI import get_ship_byName,get_AccountIdByName
 from collections import defaultdict, namedtuple
 from nonebot import get_driver
@@ -17,6 +16,7 @@ from nonebot.log import logger
 from httpx import ConnectTimeout
 from asyncio.exceptions import TimeoutError
 from bs4 import BeautifulSoup
+from datetime import datetime
 
 dir_path = Path(__file__).parent
 template_path = dir_path / "template"
@@ -29,7 +29,7 @@ headers = {
 }
 
 ShipSlectState = namedtuple("ShipSlectState", ['state','SlectIndex','SelectList'])
-SecletProcess = defaultdict(lambda: ShipSlectState(False, None, None))
+ShipSecletProcess = defaultdict(lambda: ShipSlectState(False, None, None))
 
 async def get_ShipInfo(qqid,info,bot):
     try:
@@ -88,16 +88,18 @@ async def get_ShipInfo(qqid,info,bot):
                     for each in shipList:
                         flag += 1
                         msg += f"{flag}：{tiers[each[3]-1]} {each[1]}\n"
-                    SecletProcess[qqid] = ShipSlectState(False, None, shipList)
+                    ShipSecletProcess[qqid] = ShipSlectState(False, None, shipList)
                     img = await text_to_pic(text=msg,css_path = str(template_path/"text-ship.css"),width=250) 
                     await bot.send(MessageSegment.image(img))
                     a = 0
-                    while a < 200 and not SecletProcess[qqid].state:
+                    while a < 40 and not ShipSecletProcess[qqid].state:
                         a += 1
-                        await asyncio.sleep(0.1)
-                    if SecletProcess[qqid].state and SecletProcess[qqid].SlectIndex <= len(shipList):
-                        params["shipId"] = shipList[SecletProcess[qqid].SlectIndex-1][0]
+                        await asyncio.sleep(0.5)
+                    if ShipSecletProcess[qqid].state and ShipSecletProcess[qqid].SlectIndex <= len(shipList):
+                        params["shipId"] = shipList[ShipSecletProcess[qqid].SlectIndex-1][0]
+                        ShipSecletProcess[qqid] = ShipSlectState(False, None, None)
                     else:
+                        ShipSecletProcess[qqid] = ShipSlectState(False, None, None)
                         return '已超时退出'
             else:
                 return '找不到船'
@@ -107,8 +109,8 @@ async def get_ShipInfo(qqid,info,bot):
         ranking = await get_MyShipRank_yuyuko(params)
         async with httpx.AsyncClient(headers=headers) as client:
             resp = await client.get(url, params=params, timeout=20)
-            logger.info(f"本次请求返回的状态码:{resp.status_code}")
             result = resp.json()
+            logger.info(f"本次请求返回的状态码:{result['code']}")
             logger.info(f"本次请求服务器计算时间:{result['queryTime']}")
         if result['code'] == 200 and result['data']:
             template = env.get_template("wws-ship.html")
@@ -118,12 +120,10 @@ async def get_ShipInfo(qqid,info,bot):
             return await html_to_pic(content, wait=0, viewport={"width": 800, "height": 100})
         elif result['code'] == 403:
             return f"{result['message']}\n请先绑定账号"
-        elif result['code'] == 404 or result['code'] == 405:
-            return f"{result['message']}"
         elif result['code'] == 500:
             return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
         else:
-            return 'wuwuu好像出了点问题，可能是网络问题，过一会儿还是不行的话请联系麻麻~'
+            return f"{result['message']}"
     except (TimeoutError, ConnectTimeout):
         logger.warning(traceback.format_exc())
         return '请求超时了，请过会儿再尝试哦~'
@@ -195,4 +195,116 @@ async def post_MyShipRank_yuyuko(accountId,ranking,serverId,shipId):
             return
     except Exception:
         logger.error(traceback.format_exc())
-        return
\ No newline at end of file
+        return
+    
+    
+async def get_ShipInfoRecent(qqid,info,bot):
+    try:
+        params,day = None,0
+        if datetime.now().hour < 7:
+            day = 1
+        if isinstance(info,List):
+            for i in info:              #查找日期,没找到默认一天
+                if str(i).isdigit():
+                    if int(i) <= 30:
+                        day = int(i)
+                    else:
+                        day = 30
+                    info.remove(i)
+            for flag,i in enumerate(info):              #是否包含me或@，包含则调用平台接口
+                if i == 'me':
+                    url = 'https://api.wows.linxun.link/api/wows/recent/v2/recent/info/ship'
+                    params = {
+                    "server": "QQ",
+                    "accountId": qqid,
+                    "day": day
+                    }
+                    info.remove("me")
+                match = re.search(r"CQ:at,qq=(\d+)",i)
+                if match:
+                    url = 'https://api.wows.linxun.link/api/wows/recent/v2/recent/info/ship'
+                    params = {
+                    "server": "QQ",
+                    "accountId": match.group(1),
+                    "day": day
+                    }
+                    info[flag] = str(i).replace(f"[{match.group(0)}]",'')
+                    if not info[flag]:
+                        info.remove('')
+                    break
+            if not params and len(info) == 3:
+                param_server,info = await match_keywords(info,servers)
+                if param_server:
+                    param_accountid = await get_AccountIdByName(param_server,str(info[0]))      #剩余列表第一个是否为游戏名
+                    if param_accountid and param_accountid != 404:
+                        info.remove(info[0])
+                        url = 'https://api.wows.linxun.link/api/wows/recent/v2/recent/info/ship'
+                        params = {
+                        "server": param_server,
+                        "accountId": param_accountid,
+                        "day": day
+                        }
+                    elif param_accountid == 404:
+                        return '无法查询该游戏昵称Orz，请检查昵称是否存在'
+                    else:
+                        return '发生了错误，有可能是网络波动，请稍后再试'
+                else:
+                    return '服务器参数似乎输错了呢'
+            elif params and len(info) == 1:
+                logger.info(f"{params}")
+            elif params:
+                return '您似乎准备用查询自己的单船近期战绩，请检查参数中是否带有船名，以空格区分'
+            else:
+                return '您似乎准备用游戏昵称查询单船近期战绩，请检查参数中是否包含服务器、游戏昵称和船名，以空格区分'
+            shipList = await get_ship_byName(str(info[0]))
+            logger.info(f"{shipList}")
+            if shipList:
+                if len(shipList) < 2:
+                    params["shipId"] = shipList[0][0]
+                else:
+                    msg = f'存在多条名字相似的船\n请在20秒内选择对应的序号\n================\n'
+                    flag = 0
+                    for each in shipList:
+                        flag += 1
+                        msg += f"{flag}：{tiers[each[3]-1]} {each[1]}\n"
+                    ShipSecletProcess[qqid] = ShipSlectState(False, None, shipList)
+                    img = await text_to_pic(text=msg,css_path = template_path/"text-ship.css",width=250)
+                    await bot.send(MessageSegment.image(img))
+                    a = 0
+                    while a < 40 and not ShipSecletProcess[qqid].state:
+                        a += 1
+                        await asyncio.sleep(0.5)
+                    if ShipSecletProcess[qqid].state and ShipSecletProcess[qqid].SlectIndex <= len(shipList):
+                        params["shipId"] = shipList[ShipSecletProcess[qqid].SlectIndex-1][0]
+                        ShipSecletProcess[qqid] = ShipSlectState(False, None, None)
+                    else:
+                        ShipSecletProcess[qqid] = ShipSlectState(False, None, None)
+                        return '已超时退出'
+            else:
+                return '找不到船'
+        else:
+            return '参数似乎出了问题呢'
+        logger.info(f"下面是本次请求的参数，如果遇到了问题，请将这部分连同报错日志一起发送给麻麻哦\n{params}")
+        async with httpx.AsyncClient(headers=headers) as client:
+            resp = await client.get(url, params=params, timeout=20)
+            result = resp.json()
+        if result['code'] == 200 and result['data']:
+            template = env.get_template("wws-ship-recent.html")
+            template_data = await set_shipRecentparams(result['data'])
+            content = await template.render_async(template_data)
+            return await html_to_pic(content, wait=0, viewport={"width": 800, "height": 100})
+        elif result['code'] == 403:
+            return f"{result['message']}\n请先绑定账号"
+        elif result['code'] == 500:
+            return f"{result['message']}\n这是服务器问题，请联系雨季麻麻"
+        else:
+            return f"{result['message']}"
+    except (TimeoutError, ConnectTimeout):
+        logger.warning(traceback.format_exc())
+        return '请求超时了，请过会儿再尝试哦~'
+    except ActionFailed:
+        logger.warning(traceback.format_exc())
+        return '由于风控或禁言，无法发送消息'
+    except Exception:
+        logger.error(traceback.format_exc())
+        return 'wuwuu好像出了点问题，过一会儿还是不行的话请联系麻麻~'
\ No newline at end of file
